SquidSonar (squid_sonar v0.1.1)

Copy Markdown View Source

Embeddable runtime dashboard for Squid Mesh.

SquidSonar mounts inside a Phoenix host application and provides a read-only dashboard for inspecting Squid Mesh workflow runs. Use SquidSonar.Router to add the dashboard routes to the host router.